@@ -1,11 +1,11 @@
+#[cfg(not(target_family = "wasm"))]
 use std::time::Duration;
 
+use crate::GraphQLApiFailure;
 use anyhow::{bail, Context as _};
 use cynic::{http::CynicReqwestError, GraphQlResponse, Operation};
 use url::Url;
 
-use crate::GraphQLApiFailure;
-
 /// API client for the Wasmer API.
 ///
 /// Use the queries in [`crate::queries`] to interact with the API.
@@ -53,11 +53,18 @@ impl WasmerClient {
     }
 
     pub fn new(graphql_endpoint: Url, user_agent: &str) -> Result<Self, anyhow::Error> {
+        #[cfg(all(target_arch = "wasm32", target_os = "unknown"))]
+        let client = reqwest::Client::builder()
+            .build()
+            .context("could not construct http client")?;
+
+        #[cfg(not(all(target_arch = "wasm32", target_os = "unknown")))]
         let client = reqwest::Client::builder()
             .connect_timeout(Duration::from_secs(10))
             .timeout(Duration::from_secs(90))
             .build()
             .context("could not construct http client")?;
+
         Self::new_with_client(client, graphql_endpoint, user_agent)
     }
 
