@@ -1,28 +1,202 @@
-use std::{collections::HashSet, pin::Pin, time::Duration};
+use std::{collections::HashSet, time::Duration};
 
 use anyhow::{bail, Context};
 use cynic::{MutationBuilder, QueryBuilder};
 use edge_schema::schema::NetworkTokenV1;
-use futures::{Stream, StreamExt};
+use futures::StreamExt;
+use merge_streams::MergeStreams;
 use time::OffsetDateTime;
 use tracing::Instrument;
 use url::Url;
 use wasmer_config::package::PackageIdent;
 
 use crate::{
-    types::{
-        self, CreateNamespaceVars, DeployApp, DeployAppConnection, DeployAppVersion,
-        DeployAppVersionConnection, DnsDomain, GetAppTemplateFromSlugVariables,
-        GetAppTemplatesFromFrameworkVars, GetAppTemplatesFromLanguageVars, GetAppTemplatesVars,
-        GetCurrentUserWithAppsVars, GetDeployAppAndVersion, GetDeployAppVersionsVars,
-        GetNamespaceAppsVars, GetSignedUrlForPackageUploadVariables, GetTemplateFrameworksVars,
-        GetTemplateLanguagesVars, Log, LogStream, PackageVersionConnection, PublishDeployAppVars,
-        PushPackageReleasePayload, SignedUrl, TagPackageReleasePayload,
-        UpsertDomainFromZoneFileVars,
-    },
+    types::{self, *},
     GraphQLApiFailure, WasmerClient,
 };
 
+pub async fn get_app_secret_value_by_id(
+    client: &WasmerClient,
+    secret_id: impl Into<String>,
+) -> Result<Option<String>, anyhow::Error> {
+    client
+        .run_graphql_strict(types::GetAppSecretValue::build(
+            GetAppSecretValueVariables {
+                id: types::Id::from(secret_id),
+            },
+        ))
+        .await
+        .map(|v| v.get_secret_value)
+}
+
+pub async fn get_app_secret_by_name(
+    client: &WasmerClient,
+    app_id: impl Into<String>,
+    name: impl Into<String>,
+) -> Result<Option<Secret>, anyhow::Error> {
+    client
+        .run_graphql_strict(types::GetAppSecret::build(GetAppSecretVariables {
+            app_id: types::Id::from(app_id),
+            secret_name: name.into(),
+        }))
+        .await
+        .map(|v| v.get_app_secret)
+}
+
+/// Update or create an app secret.
+pub async fn upsert_app_secret(
+    client: &WasmerClient,
+    app_id: impl Into<String>,
+    name: impl Into<String>,
+    value: impl Into<String>,
+) -> Result<Option<UpsertAppSecretPayload>, anyhow::Error> {
+    client
+        .run_graphql_strict(types::UpsertAppSecret::build(UpsertAppSecretVariables {
+            app_id: cynic::Id::from(app_id.into()),
+            name: name.into().as_str(),
+            value: value.into().as_str(),
+        }))
+        .await
+        .map(|v| v.upsert_app_secret)
+}
+
+/// Update or create app secrets in bulk.
+pub async fn upsert_app_secrets(
+    client: &WasmerClient,
+    app_id: impl Into<String>,
+    secrets: impl IntoIterator<Item = (impl Into<String>, impl Into<String>)>,
+) -> Result<Option<UpsertAppSecretsPayload>, anyhow::Error> {
+    client
+        .run_graphql_strict(types::UpsertAppSecrets::build(UpsertAppSecretsVariables {
+            app_id: cynic::Id::from(app_id.into()),
+            secrets: Some(
+                secrets
+                    .into_iter()
+                    .map(|(name, value)| SecretInput {
+                        name: name.into(),
+                        value: value.into(),
+                    })
+                    .collect(),
+            ),
+        }))
+        .await
+        .map(|v| v.upsert_app_secrets)
+}
+
+/// Load all secrets of an app.
+///
+/// Will paginate through all versions and return them in a single list.
+pub async fn get_all_app_secrets_filtered(
+    client: &WasmerClient,
+    app_id: impl Into<String>,
+    names: impl IntoIterator<Item = impl Into<String>>,
+) -> Result<Vec<Secret>, anyhow::Error> {
+    let mut vars = GetAllAppSecretsVariables {
+        after: None,
+        app_id: types::Id::from(app_id),
+        before: None,
+        first: None,
+        last: None,
+        offset: None,
+        names: Some(names.into_iter().map(|s| s.into()).collect()),
+    };
+
+    let mut all_secrets = Vec::<Secret>::new();
+
+    loop {
+        let page = get_app_secrets(client, vars.clone()).await?;
+        if page.edges.is_empty() {
+            break;
+        }
+
+        for edge in page.edges {
+            let edge = match edge {
+                Some(edge) => edge,
+                None => continue,
+            };
+            let version = match edge.node {
+                Some(item) => item,
+                None => continue,
+            };
+
+            all_secrets.push(version);
+
+            // Update pagination.
+            vars.after = Some(edge.cursor);
+        }
+    }
+
+    Ok(all_secrets)
+}
+
+/// Load all secrets of an app.
+///
+/// Will paginate through all versions and return them in a single list.
+pub async fn get_all_app_secrets(
+    client: &WasmerClient,
+    app_id: impl Into<String>,
+) -> Result<Vec<Secret>, anyhow::Error> {
+    let mut vars = GetAllAppSecretsVariables {
+        after: None,
+        app_id: types::Id::from(app_id),
+        before: None,
+        first: None,
+        last: None,
+        offset: None,
+        names: None,
+    };
+
+    let mut all_secrets = Vec::<Secret>::new();
+
+    loop {
+        let page = get_app_secrets(client, vars.clone()).await?;
+        if page.edges.is_empty() {
+            break;
+        }
+
+        for edge in page.edges {
+            let edge = match edge {
+                Some(edge) => edge,
+                None => continue,
+            };
+            let version = match edge.node {
+                Some(item) => item,
+                None => continue,
+            };
+
+            all_secrets.push(version);
+
+            // Update pagination.
+            vars.after = Some(edge.cursor);
+        }
+    }
+
+    Ok(all_secrets)
+}
+
+/// Retrieve secrets for an app.
+pub async fn get_app_secrets(
+    client: &WasmerClient,
+    vars: GetAllAppSecretsVariables,
+) -> Result<SecretConnection, anyhow::Error> {
+    let res = client
+        .run_graphql_strict(types::GetAllAppSecrets::build(vars))
+        .await?;
+    res.get_app_secrets.context("app not found")
+}
+
+pub async fn delete_app_secret(
+    client: &WasmerClient,
+    secret_id: impl Into<String>,
+) -> Result<Option<DeleteAppSecretPayload>, anyhow::Error> {
+    client
+        .run_graphql_strict(types::DeleteAppSecret::build(DeleteAppSecretVariables {
+            id: types::Id::from(secret_id.into()),
+        }))
+        .await
+        .map(|v| v.delete_app_secret)
+}
+
 /// Load a webc package from the registry.
 ///
 /// NOTE: this uses the public URL instead of the download URL available through
@@ -958,8 +1132,7 @@ pub async fn user_accessible_apps(
     impl futures::Stream<Item = Result<Vec<types::DeployApp>, anyhow::Error>> + '_,
     anyhow::Error,
 > {
-    let apps: Pin<Box<dyn Stream<Item = Result<Vec<DeployApp>, anyhow::Error>> + Send + Sync>> =
-        Box::pin(user_apps(client).await);
+    let user_apps = user_apps(client).await;
 
     // Get all aps in user-accessible namespaces.
     let namespace_res = client
@@ -979,17 +1152,13 @@ pub async fn user_accessible_apps(
         .map(|node| node.name.clone())
         .collect::<Vec<_>>();
 
-    let mut all_apps = vec![apps];
+    let mut ns_apps = vec![];
     for ns in namespace_names {
-        let apps: Pin<Box<dyn Stream<Item = Result<Vec<DeployApp>, anyhow::Error>> + Send + Sync>> =
-            Box::pin(namespace_apps(client, ns).await);
-
-        all_apps.push(apps);
+        let apps = namespace_apps(client, ns).await;
+        ns_apps.push(apps);
     }
 
-    let apps = futures::stream::select_all(all_apps);
-
-    Ok(apps)
+    Ok((user_apps, ns_apps.merge()).merge())
 }
 
 /// Get apps for a specific namespace.
@@ -1351,10 +1520,15 @@ fn get_app_logs(
                 if page.is_empty() {
                     if watch {
                         /*
-                            TODO: the resolution of watch should be configurable
-                            TODO: should this be async?
-                        */
+                         * [TODO]: The resolution here should be configurable.
+                         */
+
+                        #[cfg(all(target_arch = "wasm32", target_os = "unknown"))]
+                        std::thread::sleep(Duration::from_secs(1));
+
+                        #[cfg(not(all(target_arch = "wasm32", target_os = "unknown")))]
                         tokio::time::sleep(Duration::from_secs(1)).await;
+
                         continue;
                     }
 
