@@ -58,7 +58,7 @@ mod queries {
         pub viewer: Option<UserWithNamespaces>,
     }
 
-    #[derive(cynic::QueryFragment, Debug)]
+    #[derive(cynic::QueryFragment, Debug, serde::Serialize)]
     pub struct User {
         pub id: cynic::Id,
         pub username: String,
@@ -1186,6 +1186,131 @@ mod queries {
         pub version: Option<Node>,
     }
 
+    #[derive(cynic::QueryVariables, Debug)]
+    pub struct DeleteAppSecretVariables {
+        pub id: cynic::Id,
+    }
+
+    #[derive(cynic::QueryFragment, Debug)]
+    #[cynic(graphql_type = "Mutation", variables = "DeleteAppSecretVariables")]
+    pub struct DeleteAppSecret {
+        #[arguments(input: { id: $id })]
+        pub delete_app_secret: Option<DeleteAppSecretPayload>,
+    }
+
+    #[derive(cynic::QueryFragment, Debug)]
+    pub struct DeleteAppSecretPayload {
+        pub success: bool,
+    }
+    #[derive(cynic::QueryVariables, Debug, Clone)]
+    pub struct GetAllAppSecretsVariables {
+        pub after: Option<String>,
+        pub app_id: cynic::Id,
+        pub before: Option<String>,
+        pub first: Option<i32>,
+        pub last: Option<i32>,
+        pub offset: Option<i32>,
+        pub names: Option<Vec<String>>,
+    }
+
+    #[derive(cynic::QueryFragment, Debug)]
+    #[cynic(graphql_type = "Query", variables = "GetAllAppSecretsVariables")]
+    pub struct GetAllAppSecrets {
+        #[arguments(appId: $app_id, after: $after, before: $before, first: $first, last: $last, offset: $offset, names: $names)]
+        pub get_app_secrets: Option<SecretConnection>,
+    }
+
+    #[derive(cynic::QueryFragment, Debug)]
+    pub struct SecretConnection {
+        pub edges: Vec<Option<SecretEdge>>,
+        pub page_info: PageInfo,
+        pub total_count: Option<i32>,
+    }
+
+    #[derive(cynic::QueryFragment, Debug)]
+    pub struct SecretEdge {
+        pub cursor: String,
+        pub node: Option<Secret>,
+    }
+
+    #[derive(cynic::QueryVariables, Debug)]
+    pub struct GetAppSecretVariables {
+        pub app_id: cynic::Id,
+        pub secret_name: String,
+    }
+
+    #[derive(cynic::QueryFragment, Debug)]
+    #[cynic(graphql_type = "Query", variables = "GetAppSecretVariables")]
+    pub struct GetAppSecret {
+        #[arguments(appId: $app_id, secretName: $secret_name)]
+        pub get_app_secret: Option<Secret>,
+    }
+
+    #[derive(cynic::QueryVariables, Debug)]
+    pub struct GetAppSecretValueVariables {
+        pub id: cynic::Id,
+    }
+
+    #[derive(cynic::QueryFragment, Debug)]
+    #[cynic(graphql_type = "Query", variables = "GetAppSecretValueVariables")]
+    pub struct GetAppSecretValue {
+        #[arguments(id: $id)]
+        pub get_secret_value: Option<String>,
+    }
+
+    #[derive(cynic::QueryVariables, Debug)]
+    pub struct UpsertAppSecretVariables<'a> {
+        pub app_id: cynic::Id,
+        pub name: &'a str,
+        pub value: &'a str,
+    }
+
+    #[derive(cynic::QueryFragment, Debug)]
+    #[cynic(graphql_type = "Mutation", variables = "UpsertAppSecretVariables")]
+    pub struct UpsertAppSecret {
+        #[arguments(input: { appId: $app_id, name: $name, value: $value })]
+        pub upsert_app_secret: Option<UpsertAppSecretPayload>,
+    }
+
+    #[derive(cynic::QueryFragment, Debug)]
+    pub struct UpsertAppSecretPayload {
+        pub secret: Secret,
+        pub success: bool,
+    }
+
+    #[derive(cynic::QueryVariables, Debug)]
+    pub struct UpsertAppSecretsVariables {
+        pub app_id: cynic::Id,
+        pub secrets: Option<Vec<SecretInput>>,
+    }
+
+    #[derive(cynic::QueryFragment, Debug)]
+    #[cynic(graphql_type = "Mutation", variables = "UpsertAppSecretsVariables")]
+    pub struct UpsertAppSecrets {
+        #[arguments(input: { appId: $app_id, secrets: $secrets })]
+        pub upsert_app_secrets: Option<UpsertAppSecretsPayload>,
+    }
+
+    #[derive(cynic::QueryFragment, Debug)]
+    pub struct UpsertAppSecretsPayload {
+        pub secrets: Vec<Option<Secret>>,
+        pub success: bool,
+    }
+
+    #[derive(cynic::InputObject, Debug)]
+    pub struct SecretInput {
+        pub name: String,
+        pub value: String,
+    }
+    #[derive(cynic::QueryFragment, Debug, Serialize)]
+    pub struct Secret {
+        #[serde(skip_serializing)]
+        pub id: cynic::Id,
+        pub name: String,
+        pub created_at: DateTime,
+        pub updated_at: DateTime,
+    }
+
     #[derive(cynic::QueryFragment, Debug, Clone, Serialize)]
     #[cynic(graphql_type = "TXTRecord")]
     pub struct TxtRecord {
