@@ -1,6 +1,8 @@
+use std::{path::Path, str::FromStr};
+
 use anyhow::{bail, Context};
 use colored::Colorize;
-use dialoguer::Confirm;
+use dialoguer::{theme::ColorfulTheme, Confirm};
 use wasmer_api::{
     global_id::{GlobalId, NodeKind},
     types::DeployApp,
@@ -94,29 +96,6 @@ impl std::str::FromStr for AppIdent {
     }
 }
 
-pub fn get_app_config_from_current_dir() -> Result<(AppConfigV1, std::path::PathBuf), anyhow::Error>
-{
-    // read the information from local `app.yaml
-    let current_dir = std::env::current_dir()?;
-    let app_config_path = current_dir.join(AppConfigV1::CANONICAL_FILE_NAME);
-
-    if !app_config_path.exists() || !app_config_path.is_file() {
-        bail!(
-            "Could not find app.yaml at path: '{}'.\nPlease specify an app like 'wasmer app get <namespace>/<name>' or 'wasmer app get <name>`'",
-            app_config_path.display()
-        );
-    }
-    // read the app.yaml
-    let raw_app_config = std::fs::read_to_string(&app_config_path)
-        .with_context(|| format!("Could not read file '{}'", app_config_path.display()))?;
-
-    // parse the app.yaml
-    let config = AppConfigV1::parse_yaml(&raw_app_config)
-        .map_err(|err| anyhow::anyhow!("Could not parse app.yaml: {err:?}"))?;
-
-    Ok((config, app_config_path))
-}
-
 /// Options for identifying an app.
 ///
 /// Provides convenience methods for resolving an app identifier or loading it
@@ -218,6 +197,22 @@ mod tests {
     }
 }
 
+/// A utility struct used by commands that need the [`AppIdent`] as a flag.
+///
+/// NOTE: Differently from [`AppIdentOpts`], the use of this struct does not entail searching the
+/// current directory for an `app.yaml` if not specified.
+#[derive(clap::Parser, Debug)]
+pub struct AppIdentFlag {
+    /// Identifier of the application.
+    ///
+    /// Valid input:
+    /// - namespace/app-name
+    /// - app-alias
+    /// - App ID
+    #[clap(long)]
+    pub app: Option<AppIdent>,
+}
+
 pub(super) async fn login_user(
     api: &ApiOpts,
     env: &WasmerEnv,
@@ -270,3 +265,46 @@ pub(super) async fn login_user(
 
     api.client()
 }
+
+pub fn get_app_config_from_dir(
+    path: &Path,
+) -> Result<(AppConfigV1, std::path::PathBuf), anyhow::Error> {
+    let app_config_path = path.join(AppConfigV1::CANONICAL_FILE_NAME);
+
+    if !app_config_path.exists() || !app_config_path.is_file() {
+        bail!(
+            "Could not find app.yaml at path: '{}'.\nPlease specify an app like 'wasmer app get <namespace>/<name>' or 'wasmer app get <name>`'",
+            app_config_path.display()
+        );
+    }
+    // read the app.yaml
+    let raw_app_config = std::fs::read_to_string(&app_config_path)
+        .with_context(|| format!("Could not read file '{}'", app_config_path.display()))?;
+
+    // parse the app.yaml
+    let config = AppConfigV1::parse_yaml(&raw_app_config)
+        .map_err(|err| anyhow::anyhow!("Could not parse app.yaml: {err:?}"))?;
+
+    Ok((config, app_config_path))
+}
+
+pub fn get_app_config_from_current_dir() -> Result<(AppConfigV1, std::path::PathBuf), anyhow::Error>
+{
+    let current_dir = std::env::current_dir()?;
+    get_app_config_from_dir(&current_dir)
+}
+
+/// Prompt for an app ident.
+#[allow(dead_code)]
+pub(crate) fn prompt_app_ident(message: &str) -> Result<AppIdent, anyhow::Error> {
+    let theme = ColorfulTheme::default();
+    loop {
+        let ident: String = dialoguer::Input::with_theme(&theme)
+            .with_prompt(message)
+            .interact_text()?;
+        match AppIdent::from_str(&ident) {
+            Ok(id) => break Ok(id),
+            Err(e) => eprintln!("{e}"),
+        }
+    }
+}
