@@ -19,6 +19,7 @@ use shared_buffer::OwnedBuffer;
 use std::path::Path;
 use std::sync::atomic::{AtomicUsize, Ordering::SeqCst};
 use std::sync::{Arc, Mutex};
+use wasmer_types::HashAlgorithm;
 #[cfg(not(target_arch = "wasm32"))]
 use wasmer_types::{
     entity::PrimaryMap, DeserializeError, FunctionBodyLike, FunctionIndex, FunctionType,
@@ -43,6 +44,7 @@ pub struct Engine {
     #[cfg(not(target_arch = "wasm32"))]
     tunables: Arc<dyn Tunables + Send + Sync>,
     name: String,
+    hash_algorithm: Option<HashAlgorithm>,
 }
 
 impl Engine {
@@ -71,6 +73,7 @@ impl Engine {
             #[cfg(not(target_arch = "wasm32"))]
             tunables: Arc::new(tunables),
             name,
+            hash_algorithm: None,
         }
     }
 
@@ -88,6 +91,16 @@ impl Engine {
         self.name.as_str()
     }
 
+    /// Sets the hash algorithm
+    pub fn set_hash_algorithm(&mut self, hash_algorithm: Option<HashAlgorithm>) {
+        self.hash_algorithm = hash_algorithm;
+    }
+
+    /// Returns the hash algorithm
+    pub fn hash_algorithm(&self) -> Option<HashAlgorithm> {
+        self.hash_algorithm
+    }
+
     /// Returns the deterministic id of this engine
     pub fn deterministic_id(&self) -> &str {
         // TODO: add a `deterministic_id` to the Compiler, so two
@@ -130,6 +143,7 @@ impl Engine {
             #[cfg(not(target_arch = "wasm32"))]
             tunables: Arc::new(tunables),
             name: "engine-headless".to_string(),
+            hash_algorithm: None,
         }
     }
 
@@ -176,6 +190,7 @@ impl Engine {
             self,
             binary,
             self.tunables.as_ref(),
+            self.hash_algorithm,
         )?))
     }
 
