@@ -1633,13 +1633,11 @@ mod test_filesystem {
         let fs = FileSystem::default();
 
         assert!(
-            matches!(
-                fs.new_open_options()
-                    .write(true)
-                    .create_new(true)
-                    .open(path!("/foo.txt")),
-                Ok(_)
-            ),
+            fs.new_open_options()
+                .write(true)
+                .create_new(true)
+                .open(path!("/foo.txt"))
+                .is_ok(),
             "creating a new file",
         );
 
@@ -1712,23 +1710,19 @@ mod test_filesystem {
         assert_eq!(fs.create_dir(path!("/bar")), Ok(()), "creating `bar`");
         assert_eq!(fs.create_dir(path!("/baz")), Ok(()), "creating `bar`");
         assert!(
-            matches!(
-                fs.new_open_options()
-                    .write(true)
-                    .create_new(true)
-                    .open(path!("/a.txt")),
-                Ok(_)
-            ),
+            fs.new_open_options()
+                .write(true)
+                .create_new(true)
+                .open(path!("/a.txt"))
+                .is_ok(),
             "creating `a.txt`",
         );
         assert!(
-            matches!(
-                fs.new_open_options()
-                    .write(true)
-                    .create_new(true)
-                    .open(path!("/b.txt")),
-                Ok(_)
-            ),
+            fs.new_open_options()
+                .write(true)
+                .create_new(true)
+                .open(path!("/b.txt"))
+                .is_ok(),
             "creating `b.txt`",
         );
 
@@ -1793,7 +1787,7 @@ mod test_filesystem {
             ),
             "checking entry #5",
         );
-        assert!(matches!(readdir.next(), None), "no more entries");
+        assert!(readdir.next().is_none(), "no more entries");
     }
 
     #[tokio::test]
@@ -1813,13 +1807,11 @@ mod test_filesystem {
             "creating `qux`",
         );
         assert!(
-            matches!(
-                fs.new_open_options()
-                    .write(true)
-                    .create_new(true)
-                    .open(path!("/foo/bar/baz/qux/hello.txt")),
-                Ok(_)
-            ),
+            fs.new_open_options()
+                .write(true)
+                .create_new(true)
+                .open(path!("/foo/bar/baz/qux/hello.txt"))
+                .is_ok(),
             "creating `hello.txt`",
         );
 
@@ -1921,21 +1913,21 @@ mod test_filesystem {
         let other = FileSystem::default();
         crate::ops::create_dir_all(&other, "/a/x").unwrap();
         other
-            .insert_ro_file(&Path::new("/a/x/a.txt"), Cow::Borrowed(b"a"))
+            .insert_ro_file(Path::new("/a/x/a.txt"), Cow::Borrowed(b"a"))
             .unwrap();
         other
-            .insert_ro_file(&Path::new("/a/x/b.txt"), Cow::Borrowed(b"b"))
+            .insert_ro_file(Path::new("/a/x/b.txt"), Cow::Borrowed(b"b"))
             .unwrap();
         other
-            .insert_ro_file(&Path::new("/a/x/c.txt"), Cow::Borrowed(b"c"))
+            .insert_ro_file(Path::new("/a/x/c.txt"), Cow::Borrowed(b"c"))
             .unwrap();
 
-        let out = other.read_dir(&Path::new("/")).unwrap();
+        let out = other.read_dir(Path::new("/")).unwrap();
         dbg!(&out);
 
         let other: Arc<dyn crate::FileSystem + Send + Sync> = Arc::new(other);
 
-        main.mount_directory_entries(&Path::new("/"), &other, &Path::new("/a"))
+        main.mount_directory_entries(Path::new("/"), &other, Path::new("/a"))
             .unwrap();
 
         let mut buf = Vec::new();
@@ -1943,7 +1935,7 @@ mod test_filesystem {
         let mut f = main
             .new_open_options()
             .read(true)
-            .open(&Path::new("/x/a.txt"))
+            .open(Path::new("/x/a.txt"))
             .unwrap();
         f.read_to_end(&mut buf).await.unwrap();
 
