@@ -7,6 +7,11 @@ impl JournalEffector {
     ) -> anyhow::Result<()> {
         let env = ctx.data();
         if !env.should_journal() {
+            tracing::trace!(
+                "skipping journal event save (enable={}, replaying={})",
+                env.enable_journal,
+                env.replaying_journal
+            );
             return Ok(());
         }
 
