@@ -1,5 +1,5 @@
 pub mod common;
-mod console;
+pub mod console;
 pub mod tty;
 
 pub mod command;
